--[[--------------------------------------------------------------------------------------------------
Modul: 		ConnectionChecker
Version: 	004
Author: 	Torben Ratzlaff
Website: 	screenheadmedia.com

Purpose:
A module to check the connection to a certain server or the internet connection in general.

----------------------------------------------------------------------------------------------------]]


--[[--------------------------------------------------------------------------------------------------
How to use:

ConnectionChecker.testConnection(serverName) 
--tests the connection to the desired server and return true or false. Pings the google server at default
--serverName 	- name of the server you want to check

ConnectionChecker.alertConnection(serverName, alertData, listener) 
--like ConnectionChecker.testConnection(), but also calls a listener function, if a connection is available or shows up an alert if not
--serverName 	- name of the server you want to check
--alertData		- the alerts data table, by default: {title = "CONNECTION ERROR", caption = "No network connection available.",  buttons = {"Close"}}
--listener 		- a listener function

ConnectionChecker.setDefaultAlert(alertData) --set a default alertData for lokalizing purposes
--alertData		- the alerts data table, by default: {title = "CONNECTION ERROR", caption = "No network connection available.",  buttons = {"Close"}}

ConnectionChecker.setServer(name, URL) --sets or adds a server that can be checked later
--name 			- name of the server you want to set/add
--URL 			- url of the server you want to set/add

----------------------------------------------------------------------------------------------------]]


local socket = require("socket")

local socket_tcp = socket.tcp
local native_showAlert = native.showAlert
local type = type
local assert = assert

local checkedURLs = 
{
	general = "www.google.com",
	twitter = "www.twitter.com",
	facebook = "www.facebook.com",
}

local defaultAlert = {title = "CONNECTION ERROR", caption = "No network connection available.",  buttons = {"Close"}}


local ConnectionChecker = {}

-- Tests the connection and returns true or false
function ConnectionChecker.testConnection(serverName)
	local serverName = serverName or "general"
	local url = assert(checkedURLs[serverName], "ConnectionChecker.testConnection - No server with the name '"..serverName.."' specified.")

	local test = socket_tcp()
	test:settimeout(500)
		
	local testResult = test:connect(url, 80)
		
	test:close()
	
	if testResult ~= nil then
		return true
	end
	
	return false
end


-- Tests the connection and opens an alert if there is no connection available. It also runs a provided listener function.
function ConnectionChecker.alertConnection(serverName, alertData, listener)
	local connection = ConnectionChecker.testConnection(serverName)

	local function alertListener(event)
		 if "clicked" == event.action then
			local i = event.index
			if 1 == i then
			
			end
		end
	end
	
	if listener and connection == true then
		listener()
	else
		if not alertData or alertData == "default" then
			alertData = defaultAlert
		end
		native_showAlert( alertData.title, alertData.caption, alertData.buttons, alertListener)
	end
end


-- Sets the default alert message. Standard form is {title = "ALERT TITLE", caption = "Alert message",  buttons = {"Close button"}}
function ConnectionChecker.setDefaultAlert(alertData)
	assert(alertData, "ConnectionChecker.setDefaultAlert - You have to specify an alert data [table]")
	defaultAlert = alertData
end


-- Sets the URL for a specific server which could be checked later
function ConnectionChecker.setServer(name, URL)
	assert(type(name) == "string" and type(URL) == "string", "ConnectionChecker.setServer - You have to specify a servername [string] and an URL [string]")

	checkedURLs[name] = URL
end


return ConnectionChecker